/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.apache.geronimo.samples.bank.ejb;

import java.util.Collection;

import javax.ejb.EntityBean;

/**
 * 
 * @ejb.bean type="CMP" cmp-version="2.x" name="Customer"
 *           local-jndi-name="java:comp/env/ejb/Customer" view-type="local"
 *           primkey-field="customerId"
 * 
 * @ejb.interface generate="local"
 *                local-class="org.apache.geronimo.samples.bank.ejb.CustomerLocal"
 * @ejb.home generate="local"
 *           local-class="org.apache.geronimo.samples.bank.ejb.CustomerHomeLocal"
 * 
 * 
 * @web.ejb-local-ref name="ejb/Customer" type="Entity"
 *                    home="org.apache.geronimo.samples.bank.ejb.CustomerHomeLocal"
 *                    local="org.apache.geronimo.samples.bank.ejb.CustomerLocal"
 *                    link="Customer"
 * 
 * @ejb.persistence table-name="customer"
 * 
 * 
 */
public abstract class CustomerBean implements EntityBean {

	/**
	 * @ejb.pk-field
	 * @ejb.persistence column-name="CUST_ID"
	 * @ejb.interface-method view-type="local"
	 * @return
	 */
	public abstract String getCustomerId();

	/**
	 * @ejb.interface-method view-type="local"
	 * @param id
	 */
	public abstract void setCustomerId(String id);
	
	/**
	 * @ejb.persistence column-name="CUST_NAME"
	 * @ejb.interface-method view-type="local"
	 * @return
	 */
	public abstract String getCustomerName();
	
	/**
	 * @ejb.interface-method view-type="local"
	 * @param name
	 */
	public abstract void setCustomerName(String name);
	
	
	/**
	 * @ejb.interface-method view-type="local"
	 * @ejb.relation name = "Customer-Account" target-ejb = "Account"
	 * 					target-role-name = "Account-to-Customer"
	 * 					role-name = "Customer-to-Account"
	 * @return
	 */
	public abstract Collection getAccounts();
	
	/**
	 * @ejb.interface-method view-type="local"
	 * @param account
	 */
	public abstract void setAccounts(Collection accounts);
	
	/**
	 * @ejb.create-method
	 */
	public java.lang.String ejbCreate(String custId) throws javax.ejb.CreateException {
		setCustomerId(custId);
		return null;
	}

	public void ejbPostCreate(String custId) throws javax.ejb.CreateException {
	}
}
