/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 * 
 *       http://www.apache.org/licenses/LICENSE-2.0
 * 
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package org.apache.geronimo.samples.bank.web;

import java.io.IOException;
import java.util.Collection;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.geronimo.samples.bank.ejb.BankManagerFacadeHomeLocal;
import org.apache.geronimo.samples.bank.ejb.BankManagerFacadeLocal;

public class CommonServiceServlet extends HttpServlet {
	
	protected void doGet(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException {
		viewRates(req, res);
	}

	protected void doPost(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException {
		doGet(req,res);
	}
	
	private void viewRates(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException{
		Context context = null; 
		String path = "/jsp/error.jsp";;
		
		try {
			context = new InitialContext();
			BankManagerFacadeHomeLocal bmHome = (BankManagerFacadeHomeLocal)context.lookup(BankManagerFacadeHomeLocal.JNDI_NAME);
			BankManagerFacadeLocal bm = bmHome.create();
			Collection rates = bm.getExchangeRates();
			req.setAttribute("rateList",rates);
			
			path = "/jsp/exchange_rates.jsp";
			
		} catch (Exception e) {
			e.printStackTrace();
		}finally{
			try {
				context.close();
			} catch (NamingException e) {
				e.printStackTrace();
			}
		}
	  getServletContext().getRequestDispatcher(path).forward(req,res);
	}


}
